@@ -58,11 +58,13 @@ class MYSQLExporter(Result):
         """
         if not self.args.mysql: return
         import MySQLdb
-        if len(obj[0] > 1):
+        if self.args.get_only_ff:
+            aq="update tw_user set tw_id=\'%s\', task_status=1 where name=\'%s\'"
+
+        else:
             print "Getting user data"
             aq= "update tw_user set tw_id=\'%s\', task_status=\'%s\', task_host=\'%s\', created_at=\'%s\', statuses_count=\'%s\', friend_count=\'%s\', followers_count=\'%s\', geo_lat=\'%s\', geo_long=\'%s\', geo_text=\'%s\' where  name=\'%s\'" ,
-        else:
-            aq="update tw_user set tw_id=\'%s\', task_status=1 where name=\'%s\'"
+
         query=[ aq,
                 "Insert into tw_userfollower (user_tw_id, follower) values (%s,%s)",
                 "Insert into tw_frienduser (friend, user_tw_id) values (%s,%s)"
@@ -192,6 +194,11 @@ class ResultsGenerator(object):
                     except Exception, e:
                         print(e)
                         pass
+                else:
+                    try:
+                        myusers.append( [ id_ , 2 ] )
+                    except Exception, e:
+                        print e
 
                 try:
                     for follower_id in user_[1]['ids']:
